/**
 * Back 2 Browser Bytecode Translator
 * Copyright (C) 2012 Jaroslav Tulach <jaroslav.tulach@apidesign.org>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. Look for COPYING file in the top folder.
 * If not, see http://opensource.org/licenses/GPL-2.0.
 */
package org.apidesign.bck2brwsr.htmlpage;

import java.lang.reflect.Method;
import java.util.logging.Level;
import java.util.logging.Logger;

/** Represents callback from Knockout.js to Java.
 *
 * @author Jaroslav Tulach <jtulach@netbeans.org>
 */
public final class KOFunction {
    private static final Logger LOG = Logger.getLogger(KOFunction.class.getName());
    private final Object model;
    private final Method method;
    
    KOFunction(Object model, String method) throws NoSuchMethodException {
        this.method = model.getClass().getDeclaredMethod(method, Object.class, Object.class);
        this.method.setAccessible(true);
        this.model = model;
    }
    
    public void call(Object data, Object ev) {
        try {
            this.method.invoke(model, data, ev);
        } catch (Throwable ex) {
            LOG.log(Level.SEVERE, "Can't call " + method + " on " + model, ex);
        }
    }
}
